@@ -253,20 +253,9 @@ class Neo4jCsvPublisher(Publisher):
 
         with open(node_file, 'r', encoding='utf8') as node_csv:
             for node_record in pandas.read_csv(node_csv, na_filter=False).to_dict(orient="records"):
-                LOGGER.info('loop time %s', str(time.time() - self.now))
-
-                self.now = time.time()
                 stmt = self.create_node_merge_statement(node_record=node_record)
-                LOGGER.info('create node statement time %s', str(time.time() - self.now))
-
-                self.now = time.time()
                 params = self._create_props_param(node_record)
-                LOGGER.info('create prop time %s', str(time.time() - self.now))
-                
-                self.now = time.time()
                 tx = self._execute_statement(stmt, tx, params)
-                LOGGER.info('neo query time %s', str(time.time() - self.now))
-                self.now = time.time()
 
         return tx
 
